==> ansible-10.0.0.tgz: lib/python3.11/site-packages/ansible_collections/cisco/ise/plugins/action/system_certificate_import.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright (c) 2024, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import absolute_import, division, print_function

__metaclass__ = type
from ansible.plugins.action import ActionBase

try:
    from ansible_collections.ansible.utils.plugins.module_utils.common.argspec_validate import (
        AnsibleArgSpecValidator,
    )
except ImportError:
    ANSIBLE_UTILS_IS_INSTALLED = False
else:
    ANSIBLE_UTILS_IS_INSTALLED = True
from ansible.errors import AnsibleActionFail
from ansible_collections.cisco.ise.plugins.plugin_utils.ise import (
    ISESDK,
    ise_argument_spec,
)

# Get common arguements specification
argument_spec = ise_argument_spec()
# Add arguments specific for this module
argument_spec.update(dict(
    admin=dict(type="bool"),
    allowExtendedValidity=dict(type="bool"),
    allowOutOfDateCert=dict(type="bool"),
    allowPortalTagTransferForSameSubject=dict(type="bool"),
    allowReplacementOfCertificates=dict(type="bool"),
    allowReplacementOfPortalGroupTag=dict(type="bool"),
    allowRoleTransferForSameSubject=dict(type="bool"),
    allowSHA1Certificates=dict(type="bool"),
    allowWildCardCertificates=dict(type="bool"),
    data=dict(type="str"),
    eap=dict(type="bool"),
    ims=dict(type="bool"),
    name=dict(type="str"),
    password=dict(type="str", no_log=True),
    portal=dict(type="bool"),
    portalGroupTag=dict(type="str"),
    privateKeyData=dict(type="str"),
    pxgrid=dict(type="bool"),
    radius=dict(type="bool"),
    saml=dict(type="bool"),
    validateCertificateExtensions=dict(type="bool"),
))

required_if = []
required_one_of = []
mutually_exclusive = []
required_together = []


class ActionModule(ActionBase):
    def __init__(self, *args, **kwargs):
        if not ANSIBLE_UTILS_IS_INSTALLED:
            raise AnsibleActionFail("ansible.utils is not installed. Execute 'ansible-galaxy collection install ansible.utils'")
        super(ActionModule, self).__init__(*args, **kwargs)
        self._supports_async = False
        self._supports_check_mode = False
        self._result = None

    # Checks the supplied parameters against the argument spec for this module
    def _check_argspec(self):
        aav = AnsibleArgSpecValidator(
            data=self._task.args,
            schema=dict(argument_spec=argument_spec),
            schema_format="argspec",
            schema_conditionals=dict(
                required_if=required_if,
                required_one_of=required_one_of,
                mutually_exclusive=mutually_exclusive,
                required_together=required_together,
            ),
            name=self._task.action,
        )
        valid, errors, self._task.args = aav.validate()
        if not valid:
            raise AnsibleActionFail(errors)

    def get_object(self, params):
        new_object = dict(
            admin=params.get("admin"),
            allow_extended_validity=params.get("allowExtendedValidity"),
            allow_out_of_date_cert=params.get("allowOutOfDateCert"),
            allow_portal_tag_transfer_for_same_subject=params.get("allowPortalTagTransferForSameSubject"),
            allow_replacement_of_certificates=params.get("allowReplacementOfCertificates"),
            allow_replacement_of_portal_group_tag=params.get("allowReplacementOfPortalGroupTag"),
            allow_role_transfer_for_same_subject=params.get("allowRoleTransferForSameSubject"),
            allow_sha1_certificates=params.get("allowSHA1Certificates"),
            allow_wild_card_certificates=params.get("allowWildCardCertificates"),
            data=params.get("data"),
            eap=params.get("eap"),
            ims=params.get("ims"),
            name=params.get("name"),
            password=params.get("password"),
            portal=params.get("portal"),
            portal_group_tag=params.get("portalGroupTag"),
            private_key_data=params.get("privateKeyData"),
            pxgrid=params.get("pxgrid"),
            radius=params.get("radius"),
            saml=params.get("saml"),
            validate_certificate_extensions=params.get("validateCertificateExtensions"),
        )
        return new_object

    def run(self, tmp=None, task_vars=None):
        self._task.diff = False
        self._result = super(ActionModule, self).run(tmp, task_vars)
        self._result["changed"] = False
        self._check_argspec()

        ise = ISESDK(params=self._task.args)

        response = ise.exec(
            family="certificates",
            function="import_system_certificate",
            params=self.get_object(self._task.args),
        ).response

        self._result.update(dict(ise_response=response))
        self._result.update(ise.exit_json())
        return self._result

==> ansible-11.4.0.tgz: lib/python3.12/site-packages/ansible_collections/cisco/ise/plugins/action/system_certificate_import.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright (c) 2024, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import absolute_import, division, print_function

__metaclass__ = type
from ansible.plugins.action import ActionBase

try:
    from ansible_collections.ansible.utils.plugins.module_utils.common.argspec_validate import (
        AnsibleArgSpecValidator,
    )
except ImportError:
    ANSIBLE_UTILS_IS_INSTALLED = False
else:
    ANSIBLE_UTILS_IS_INSTALLED = True
from ansible.errors import AnsibleActionFail
from ansible_collections.cisco.ise.plugins.plugin_utils.ise import (
    ISESDK,
    ise_argument_spec,
)

# Get common arguements specification
argument_spec = ise_argument_spec()
# Add arguments specific for this module
argument_spec.update(
    dict(
        admin=dict(type="bool"),
        allowExtendedValidity=dict(type="bool"),
        allowOutOfDateCert=dict(type="bool"),
        allowPortalTagTransferForSameSubject=dict(type="bool"),
        allowReplacementOfCertificates=dict(type="bool"),
        allowReplacementOfPortalGroupTag=dict(type="bool"),
        allowRoleTransferForSameSubject=dict(type="bool"),
        allowSHA1Certificates=dict(type="bool"),
        allowWildCardCertificates=dict(type="bool"),
        data=dict(type="str"),
        eap=dict(type="bool"),
        ims=dict(type="bool"),
        name=dict(type="str"),
        password=dict(type="str", no_log=True),
        portal=dict(type="bool"),
        portalGroupTag=dict(type="str"),
        privateKeyData=dict(type="str"),
        pxgrid=dict(type="bool"),
        radius=dict(type="bool"),
        saml=dict(type="bool"),
        validateCertificateExtensions=dict(type="bool"),
    )
)

required_if = []
required_one_of = []
mutually_exclusive = []
required_together = []


class ActionModule(ActionBase):
    def __init__(self, *args, **kwargs):
        if not ANSIBLE_UTILS_IS_INSTALLED:
            raise AnsibleActionFail(
                "ansible.utils is not installed. Execute 'ansible-galaxy collection install ansible.utils'"
            )
        super(ActionModule, self).__init__(*args, **kwargs)
        self._supports_async = False
        self._supports_check_mode = False
        self._result = None

    # Checks the supplied parameters against the argument spec for this module
    def _check_argspec(self):
        aav = AnsibleArgSpecValidator(
            data=self._task.args,
            schema=dict(argument_spec=argument_spec),
            schema_format="argspec",
            schema_conditionals=dict(
                required_if=required_if,
                required_one_of=required_one_of,
                mutually_exclusive=mutually_exclusive,
                required_together=required_together,
            ),
            name=self._task.action,
        )
        valid, errors, self._task.args = aav.validate()
        if not valid:
            raise AnsibleActionFail(errors)

    def get_object(self, params):
        new_object = dict(
            admin=params.get("admin"),
            allow_extended_validity=params.get("allowExtendedValidity"),
            allow_out_of_date_cert=params.get("allowOutOfDateCert"),
            allow_portal_tag_transfer_for_same_subject=params.get(
                "allowPortalTagTransferForSameSubject"
            ),
            allow_replacement_of_certificates=params.get(
                "allowReplacementOfCertificates"
            ),
            allow_replacement_of_portal_group_tag=params.get(
                "allowReplacementOfPortalGroupTag"
            ),
            allow_role_transfer_for_same_subject=params.get(
                "allowRoleTransferForSameSubject"
            ),
            allow_sha1_certificates=params.get("allowSHA1Certificates"),
            allow_wild_card_certificates=params.get("allowWildCardCertificates"),
            data=params.get("data"),
            eap=params.get("eap"),
            ims=params.get("ims"),
            name=params.get("name"),
            password=params.get("password"),
            portal=params.get("portal"),
            portal_group_tag=params.get("portalGroupTag"),
            private_key_data=params.get("privateKeyData"),
            pxgrid=params.get("pxgrid"),
            radius=params.get("radius"),
            saml=params.get("saml"),
            validate_certificate_extensions=params.get("validateCertificateExtensions"),
        )
        return new_object

    def run(self, tmp=None, task_vars=None):
        self._task.diff = False
        self._result = super(ActionModule, self).run(tmp, task_vars)
        self._result["changed"] = False
        self._check_argspec()

        ise = ISESDK(params=self._task.args)

        response = ise.exec(
            family="certificates",
            function="import_system_certificate",
            params=self.get_object(self._task.args),
        ).response

        self._result.update(dict(ise_response=response))
        self._result.update(ise.exit_json())
        return self._result
